@@ -224,7 +224,7 @@ def generate_substitutions_from_package(
     # Installation prefix
     data['InstallationPrefix'] = installation_prefix
     # Resolve dependencies
-    depends = package.run_depends
+    depends = package.run_depends + package.buildtool_export_depends
     build_depends = package.build_depends + package.buildtool_depends + package.test_depends
     unresolved_keys = depends + build_depends + package.replaces + package.conflicts
     resolved_deps = resolve_dependencies(unresolved_keys, os_name,
